@@ -17,8 +17,7 @@ def Flider():
     for i in range(len(save_paths)):
         try:
             completeName = os.path.join(save_paths[i], file_names[i])
-            CompleteSave = os.path.join('../save_files/', read_names[i])
-            read_file = open(CompleteSave, 'r')
+            read_file = open(read_names[i], 'r')
             write_file = open(completeName, 'w')
             write_file.write(read_file.read())
             write_file.close()
